==> whmcs-8.8.0-release.1.zip: resources/views/admin/assent/index.php <==
<?php //ICB0 72:0 81:104c                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.8.0 (8.8.0-release.1)                                      *
// * BuildId:06fc63b.326                                                  *
// * Build Date:20 Sep 2023                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPpKqWQeO6tgDbOSKYL5NtukZkJS0MNBM/iGMSUgIX8iRO/82k41JYIdCraLymDTnqRUne7yC
Uv0koZfM5Y6nnjU+75XsbD/3JmKwQyYK6WbPFRtrm79kG8FJdZleKOyJPiFNkZjsEhqdYeyzzlS+
HP4KtfzNJjXjzDZsUtkLuXKgadiuBIOzVDrcE6BQFxH+nKA2hVe6hX5pKFBe9wFis8kXGcE/GlO2
7K3enC9bSsgarbDJxt/O/B6tsdp4nFAMgsJ5jmZIeYM6qLxXZP+DkiJO4j2SigbrE/gMBu/tP3eI
aHEDUNNPI4mQOBpfkwNq5aBgjKRDHGNyRTcqHRsPmENwl+zdp74Ax2fkyHJFVCv4k1EGBzJVaSWr
DF2D1nMMs1u99RWHiEzM+9exoGCHVHkbFMhy97h4rGrD669n4/nr+e8HoNMRZfG8v7N45r4owVqh
dHB/s+xrttWnwIyJ2x3plkHAO/730ANmVbOpI7aVOiCwouzdZDQfe6jtPMN7aigNxVOFt1hqdBdg
Xz1K4L7FiKhPCP2tDMTfy1qAUAH4C/4o8DQbP/BS4X9KORY0cCPNoMZ7M7d81Si/MFj6bqO16uOC
IJ5xZEfxVa05/Rxxdj9pCISuulF0yEQi3LF8FR7v5LQsOpg0ky9cEnOvpMLPt6hO+oEDHQ3iD7BV
f13dJQwqoCk7jSB1VVJlHgahcZe9j1Ibbfee4KadYT952Z9fLrP5yJ19czflG9M2hdemMBFwkj7i
O3O7arOpuX8cgn12jmFB173eXASXEi1Bl8k1xiUWquKNBOkiQPOdnJkEGd5MEFt1LsmWuzSdP02l
Olexa2nk0doZM1GiscFJmzsYFUEWGGx6lNzNMU1SkljAq7BrXWch2W6dlehKSNa==
HR+cPxPDhSm6hnNZh/Cuxtf8HL+KjBSz2PtJSuB8G6Jxyn/aG83cmC15kAmsPr8ZjcHTvba1W5PB
y6VkP2V5r0B0gXOU4/55/YzHs0eITffSk1WZms/dAUBmqAUwNFF55TXiNDAuXK84+N2bV1mZ/1dP
K+vZFsPzR+jvh5VtJFQjtGGk3gNNzoQWaFl1T86RbIFnJr9Z3TAFJkKiprhD2oUgoggjAxVbFhYA
TyeY4jPSuOwtL8yQp1aV8z66CqUys//Ipc6WieR4sVxqAYtVQa3CZPPFyzyn0Ti2WKm6T0SSkKyu
A/1IT3Zo+nlyiUE+1sUBRl/8NwnEmg4NyVTaJ2plZYUS0m+BEwlTMRgI6BiXm6nsVAcI5BE0nxwK
TlFIj1d8FY9Drfi0SDFJNJshFTq1ByPJM31AG+KnTKUECky2O59edn8x1GmV8d5OwpcyKwBg2mT6
1/W1aVgvEML3BtIfXXs1Y92/7hQ/RN4LOMjfPMH5eGl8ZBlK9UEOIpJpSkIH0sfGYl5C5g4F5IcS
cVgqat0hqnnehzxTM/TduHI5lH8wdwrDGYU4GTQAVydJrDbMVtZznfXU9PPeyYfjj+OQmHAGWb8d
wJz3KN55okcnUPFe6LebmUjCQzyhG1T8pK5MWFDKc6J16us/OWznkQwKZN9YbYtwOBGfFi8DeeuY
dXp4yZAriSrDvmHgKY14B8jhkttlvi5wsFLJtK7eBCaPi48jLD07QqDHSTyveduPY3aoYjVZdl/u
rIvBpPCxkHlfBV726hSp7w4XyRk9B54+winAUjiU08kna/vMmnyq82muNJNlc8H340Gz6t/dyxTm
LTl575W06nh6paeg9V4hASSam/yFayZQOcb71dCazpyDEcliynQ9Ibzdq5EyOwR3obfD

==> whmcs-8.10.0-release.1.zip: resources/views/admin/assent/index.php <==
<?php //ICB0 72:0 81:104c                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.10.0 (8.10.0-release.1)                                    *
// * BuildId:dc9095d.372                                                  *
// * Build Date:23 Apr 2024                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPtE0IIBRRx8LqZFS0IqJ3do71OM25lRA0/K5G0sRv37TVL7DDQcAyBFr770jJ3DhlI+jSVDq
6ZEua0dlem3m5w1evBo9PA9Q4uZfQL1LAYE1Q2R7vqC8K/q+d8FRc4jPyfp54Q992jn8GwPM3ogn
wB/w0fP6hEuoOhyn61c2+pKP6PPYgJI8NXHpSj86OyrSMvKOcYPi9vnQGqLXzM+kgKG2MHxXzoLu
JYsZeJ6A0z2hW9+lgklHAt5uRDEm4E98OnODl5IbGwSuZRII3YMS6YWxyoJt1G1cL8EmmtgBXY6W
Oc5OoVrc3pcmH3rCHvza4tI2nUa9/zlEqsXtcDFTjRi49wMNbZPfRG6nxBTq/ydXyVV5koNrkDRv
R+r129CMCCehiMTYx4E72XC5f0fAiyuSv+qfmifmsW40Ke3EvE8cqYICn6I/lUa4OMP0g+5prD2c
JdMRkLS/5qTqlLaozknRy4+p+pkA/U3EBhDx22MbBRSz5F3Q3Q0P9sGnhm2WH9LoA2J6dsDRh7vP
EVZ+8n394dkIHf9LDlUt+vESyX+LaKjIJ499XPIKggSqgTgmeO/cnl4NfxsPRS4R5Br0amLCmv99
Pb1T7VQ9Qx1eEqRIhy8vdnb1fbQvlCwSPEH2zIrntCBPv/TFZHPg5/kr1FicjyrGM5oZP1nIj/aR
sNMFiTAfjuuuAPpeOIk63RZEvJPxR5Qt3j7ia/EQzXPah+B6iPkLWpGSDXwCUKF0kMSxgxLQ+Bvw
JGzlr9YKgvUZCiAQNv8RjCf5/ZaV1yfhKHWN8pkTqgwRAwx4kRHHjBNMEXFR/NTCfzaC+t7veWG3
OCZ0uBF2VcAfJwFy4XGHP8km5WivnEq6vrzE1XUPNgHYxUsNsY+occVqQw53sfOc=
HR+cPvKXB0/ZyvGWYf+vB6MxFITOA9qft+XKP9d8yHe6PTVutn8veprMDrexzsmOgdtyMedQiDpk
til0Rl0Fe88f/gXYnTl4yzHhaxOFU8ckuX89RA9cIxjIAzrfcAhUy7MSXYUVgwimPmldKNlCeeef
Tpix+sOROstKvhOxi1V3YLUD1whmyNlo8bLgEXiJviAoFGX2OaIxXbEhjHNHzRtWxCLB5DorKWjF
bkfYoPhmpkf2F+suHCq5PtUumB26mGlFEA1ouRxsruYPwTbCj8FAR/IjXUqrneqdegJgjfKXPj4I
3qtEUCncnn7V/6WRqvEBU8TDPV/o8hc/9FJagLf92ya6xsBmSNEuQFGsw9hBc2S10Sp9eJXlfVEz
lTuNtVtZv2KHfUhj3LVNmPZWGO3y3LfwOL2Pr0kTOzKEUdK7nbXh3pbz93SvvOOGgO482QfCLdfv
BtcYC1v7R6pBmpXVhkD9hXNo1RTwRcFwQKhMdpalzfJuTOvnMQmdpvFlTsHfTFD5+RmAyFENR+2k
HTHnaq+LXhR+yzCd8G4Ezym4MjIkLQcCr/fsPDEmFgNv5J/iXyz5AzptzL7rJbZZr3KfeDZdWQIU
kRXikuxk1rbkRaOV2TfygaoFxCeDFfO3w7/dpKcFTh+01xCf5Cqv5EmlM1M90fbNeXcWszTFMAbU
qzt1oazD4N97hhBxGF3hrlT9YHq+nBkIpAbdTpSPh84Wl0Qhi3PKBrxgGkix/LU0tOIF6r5EvceG
tnSuqG4U7KueIUZ0svSYc7YwtOqgzRq4jd/qmYh4ASJI1marylmF1jSS/VvdhD5yARa+3r9Wjw5G
cSGvK8DYkz69dVfDjEDOk6UASbVyI72OnTkmeu9gCZVlSW3dH6tr3QYRsIEJ
